import requests
from stringcolor import cs

class Translate:

 
    api_url = "http://api.funtranslations.com/translate/klingon?text="
    @staticmethod
    def Klingon(str):
        url = Translate.api_url + str 
        response = requests.get(url)
        
        if response.status_code != 200:
            raise Exception("API request failed.")
        print(cs(f'API request OK:{response.status_code}','green'))
        
        
        return response.json()["contents"]["translated"]
    



from setuptools import setup, find_packages

setup(
    name='Klingonprints',
    version='0.1.0',
    author='Ole Wegener',
    author_email='ole.wegener@aol.com',
    description='4 Theme options to change string appearance and option to translate to Klingon Language',
                
    packages=find_packages(),
    install_requires=[
        'requests',
        'string-color',
        "random"
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.0',
)


from stringcolor import cs
import random

class Theme:

    @staticmethod
    def Kling(str):
        colors = ["red","DarkRed","DarkRed2","Maroon"]
        
        newstr = ""
        for char in str:
            char = cs(char,random.choice(colors))
            
            newstr += char
        
        return newstr
        
    @staticmethod
    def Beach(str):
        colors = ["Cyan","Aqua","NavajoWhite","SkyBlue","LightYellow"]
        "red","DarkRed","DarkRed2","Maroon"
        newstr = ""
        for char in str:
            char = cs(char,random.choice(colors))
            newstr += char
        
        return newstr
    
    @staticmethod
    def Forest(str):
        colors = ["Green2","Green","DarkGreen","DarkSeaGreen","Green3"]
        
        newstr = ""
        for char in str:
            char = cs(char,random.choice(colors))
            newstr += char
        
        return newstr
    
    @staticmethod
    def Rainbow(str):
        colors = ["Green","Blue","Yellow","Orange","Purple","Red","Aqua","Fuchsia"]
        
        newstr = ""
        for char in str:
            char = cs(char,random.choice(colors))
            newstr += char
        
        return newstr



